@@ -1,6 +1,7 @@
-import json
+from aisquared.base import BaseObject
 
-class BinaryClassification:
+
+class BinaryClassification(BaseObject):
     """
     Postprocesssing configuration object for binary classification
     """
@@ -8,7 +9,7 @@ class BinaryClassification:
     def __init__(
         self,
         label_map,
-        threshold = 0.5
+        threshold=0.5
     ):
         """
         Parameters
@@ -18,23 +19,27 @@ class BinaryClassification:
         threshold : float (default 0.5)
             The threshold for the second value to the label map to be the one chosen
         """
+        super().__init__()
         self.label_map = label_map
         self.threshold = threshold
 
     @property
     def label_map(self):
         return self._label_map
+
     @label_map.setter
     def label_map(self, value):
         if not isinstance(value, list):
             raise TypeError('label_map must be a list')
         if len(value) != 2:
-            raise ValueError('label_map must have exactly two values for binary classification')
+            raise ValueError(
+                'label_map must have exactly two values for binary classification')
         self._label_map = value
 
     @property
     def threshold(self):
         return self._threshold
+
     @threshold.setter
     def threshold(self, value):
         if not isinstance(value, float):
@@ -48,16 +53,9 @@ class BinaryClassification:
         Get the configuration object as a dictionary
         """
         return {
-            'className' : 'BinaryClassification',
-            'params' : {
-                'labelMap' : self.label_map,
-                'threshold' : self.threshold
+            'className': 'BinaryClassification',
+            'params': {
+                'labelMap': self.label_map,
+                'threshold': self.threshold
             }
         }
-
-    def to_json(self):
-        """
-        Get the configuration object as a JSON string
-        """
-        return json.dumps(self.to_dict())
-        
\ No newline at end of file
