@@ -1,13 +1,15 @@
-import json
+from aisquared.base import BaseObject
 
-class ObjectDetection:
+
+class ObjectDetection(BaseObject):
     """
     Postprocessing configuration object for object detection
     """
+
     def __init__(
         self,
         label_map,
-        threshold = 0.5
+        threshold=0.5
     ):
         """
         Parameters
@@ -17,12 +19,14 @@ class ObjectDetection:
         threshold : float (default 0.5)
             The confidence threshold to identify a detection
         """
+        super().__init__()
         self.label_map = label_map
         self.threshold = threshold
 
     @property
     def label_map(self):
         return self._label_map
+
     @label_map.setter
     def label_map(self, value):
         if not isinstance(value, list):
@@ -32,6 +36,7 @@ class ObjectDetection:
     @property
     def threshold(self):
         return self._threshold
+
     @threshold.setter
     def threshold(self, value):
         if not isinstance(value, float):
@@ -45,16 +50,9 @@ class ObjectDetection:
         Get the configuration object as a dictionary
         """
         return {
-            'className' : 'ObjectDetection',
-            'params' : {
-                'labelMap' : self.label_map,
-                'threshold' : self.threshold
+            'className': 'ObjectDetection',
+            'params': {
+                'labelMap': self.label_map,
+                'threshold': self.threshold
             }
         }
-
-    def to_json(self):
-        """
-        Get the configuration object as a JSON string
-        """
-        return json.dumps(self.to_dict())
-        
\ No newline at end of file
